@@ -17,31 +17,42 @@
 package com.google.inject;
 
 import static com.google.inject.Asserts.assertContains;
-import com.google.inject.internal.util.ImmutableSet;
-import com.google.inject.internal.util.Sets;
-import com.google.inject.matcher.Matchers;
 import static com.google.inject.name.Names.named;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNotSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeTrue;
 
+import com.google.common.collect.ImmutableSet;
+import com.google.common.collect.Sets;
+import com.google.common.util.concurrent.Runnables;
+import com.google.inject.internal.Annotations;
+import com.google.inject.internal.InternalFlags;
+import com.google.inject.matcher.Matchers;
+import com.google.inject.name.Named;
 import com.google.inject.spi.InjectionPoint;
 import com.google.inject.spi.TypeEncounter;
 import com.google.inject.spi.TypeListener;
 import java.lang.reflect.Constructor;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.logging.Logger;
-import junit.framework.TestCase;
-/*if[AOP]*/
 import org.aopalliance.intercept.MethodInterceptor;
 import org.aopalliance.intercept.MethodInvocation;
-/*end[AOP]*/
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
 
-/**
- * @author crazybob@google.com (Bob Lee)
- */
-public class BindingTest extends TestCase {
+/** @author crazybob@google.com (Bob Lee) */
+@RunWith(JUnit4.class)
+public class BindingTest {
 
   static class Dependent {
     @Inject A a;
@@ -49,13 +60,17 @@ public class BindingTest extends TestCase {
     @Inject void injectBob(Bob bob) {}
   }
 
+  @Test
   public void testExplicitCyclicDependency() {
-    Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(A.class);
-        bind(B.class);
-      }
-    }).getInstance(A.class);
+    Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                bind(A.class);
+                bind(B.class);
+              }
+            })
+        .getInstance(A.class);
   }
 
   static class A { @Inject B b; }
@@ -65,21 +80,24 @@ public class BindingTest extends TestCase {
 
   static class MyModule extends AbstractModule {
 
+    @Override
     protected void configure() {
       // Linked.
       bind(Object.class).to(Runnable.class).in(Scopes.SINGLETON);
 
       // Instance.
-      bind(Runnable.class).toInstance(new Runnable() {
-        public void run() {}
-      });
+      bind(Runnable.class).toInstance(Runnables.doNothing());
 
       // Provider instance.
-      bind(Foo.class).toProvider(new Provider<Foo>() {
-        public Foo get() {
-          return new Foo();
-        }
-      }).in(Scopes.SINGLETON);
+      bind(Foo.class)
+          .toProvider(
+              new Provider<Foo>() {
+                @Override
+                public Foo get() {
+                  return new Foo();
+                }
+              })
+          .in(Scopes.SINGLETON);
 
       // Provider.
       bind(Foo.class)
@@ -97,6 +115,7 @@ public class BindingTest extends TestCase {
   static class Foo {}
 
   public static class FooProvider implements Provider<Foo> {
+    @Override
     public Foo get() {
       throw new UnsupportedOperationException();
     }
@@ -104,41 +123,50 @@ public class BindingTest extends TestCase {
 
   public static class Bar {}
 
+  @Test
   public void testBindToUnboundLinkedBinding() {
     try {
-      Guice.createInjector(new AbstractModule() {
-        protected void configure() {
-          bind(Collection.class).to(List.class);
-        }
-      });
+      Guice.createInjector(
+          new AbstractModule() {
+            @Override
+            protected void configure() {
+              bind(Collection.class).to(List.class);
+            }
+          });
       fail();
     } catch (CreationException expected) {
-      assertContains(expected.getMessage(), "No implementation for java.util.List was bound.");
+      assertContains(expected.getMessage(), "No implementation for List was bound.");
     }
   }
 
   /**
-   * This test ensures that the asEagerSingleton() scoping applies to the key,
-   * not to what the key is linked to.
+   * This test ensures that the asEagerSingleton() scoping applies to the key, not to what the key
+   * is linked to.
    */
+  @Test
   public void testScopeIsAppliedToKeyNotTarget() {
-    Injector injector = Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(Integer.class).toProvider(Counter.class).asEagerSingleton();
-        bind(Number.class).toProvider(Counter.class).asEagerSingleton();
-      }
-    });
+    Injector injector =
+        Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                bind(Integer.class).toProvider(Counter.class).asEagerSingleton();
+                bind(Number.class).toProvider(Counter.class).asEagerSingleton();
+              }
+            });
 
     assertNotSame(injector.getInstance(Integer.class), injector.getInstance(Number.class));
   }
 
   static class Counter implements Provider<Integer> {
     static AtomicInteger next = new AtomicInteger(1);
+    @Override
     public Integer get() {
       return next.getAndIncrement();
     }
   }
 
+  @Test
   public void testAnnotatedNoArgConstructor() {
     assertBindingSucceeds(PublicNoArgAnnotated.class);
     assertBindingSucceeds(ProtectedNoArgAnnotated.class);
@@ -162,7 +190,8 @@ public class BindingTest extends TestCase {
     @Inject private PrivateNoArgAnnotated() { }
   }
 
-  public void testUnannotatedNoArgConstructor() throws Exception{
+  @Test
+  public void testUnannotatedNoArgConstructor() throws Exception {
     assertBindingSucceeds(PublicNoArg.class);
     assertBindingSucceeds(ProtectedNoArg.class);
     assertBindingSucceeds(PackagePrivateNoArg.class);
@@ -199,122 +228,158 @@ public class BindingTest extends TestCase {
       Guice.createInjector().getInstance(clazz);
       fail();
     } catch (ConfigurationException expected) {
-      assertContains(expected.getMessage(),
-          "Could not find a suitable constructor in " + PrivateNoArg.class.getName(),
-          "at " + PrivateNoArg.class.getName() + ".class(BindingTest.java:");
+      assertContains(
+          expected.getMessage(),
+          "No injectable constructor for type BindingTest$PrivateNoArg",
+          "BindingTest$PrivateNoArg.class(BindingTest.java:");
     }
   }
 
+  @Test
   public void testTooManyConstructors() {
     try {
       Guice.createInjector().getInstance(TooManyConstructors.class);
       fail();
     } catch (ConfigurationException expected) {
-      assertContains(expected.getMessage(),
-          TooManyConstructors.class.getName() + " has more than one constructor annotated with " 
-              + "@Inject. Classes must have either one (and only one) constructor",
-          "at " + TooManyConstructors.class.getName() + ".class(BindingTest.java:");
+      assertContains(
+          expected.getMessage(),
+          "BindingTest$TooManyConstructors has more than one constructor annotated with "
+              + "@Inject. Injectable classes must have either one (and only one) constructor",
+          "at BindingTest$TooManyConstructors.class(BindingTest.java:");
     }
   }
 
+  @SuppressWarnings("InjectMultipleAtInjectConstructors")
   static class TooManyConstructors {
-    @Inject TooManyConstructors(Injector i) {}
-    @Inject TooManyConstructors() {}
+    @Inject
+    TooManyConstructors(Injector i) {}
+
+    @Inject
+    TooManyConstructors() {}
   }
 
+  @Test
   public void testToConstructorBinding() throws NoSuchMethodException {
     final Constructor<D> constructor = D.class.getConstructor(Stage.class);
 
-    Injector injector = Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(Object.class).toConstructor(constructor);
-      }
-    });
+    Injector injector =
+        Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                bind(Object.class).toConstructor(constructor);
+              }
+            });
 
     D d = (D) injector.getInstance(Object.class);
     assertEquals(Stage.DEVELOPMENT, d.stage);
   }
 
+  @Test
   public void testToConstructorBindingsOnParameterizedTypes() throws NoSuchMethodException {
+    @SuppressWarnings("rawtypes") // Unavoidable because class literal uses raw types.
     final Constructor<C> constructor = C.class.getConstructor(Stage.class, Object.class);
     final Key<Object> s = new Key<Object>(named("s")) {};
     final Key<Object> i = new Key<Object>(named("i")) {};
 
-    Injector injector = Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(s).toConstructor(constructor, new TypeLiteral<C<Stage>>() {});
-        bind(i).toConstructor(constructor, new TypeLiteral<C<Injector>>() {});
-      }
-    });
+    Injector injector =
+        Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                bind(s).toConstructor(constructor, new TypeLiteral<C<Stage>>() {});
+                bind(i).toConstructor(constructor, new TypeLiteral<C<Injector>>() {});
+              }
+            });
 
+    // Safe because the correct generic type was used when the constructor was bound
+    @SuppressWarnings("unchecked")
     C<Stage> one = (C<Stage>) injector.getInstance(s);
     assertEquals(Stage.DEVELOPMENT, one.stage);
     assertEquals(Stage.DEVELOPMENT, one.t);
     assertEquals(Stage.DEVELOPMENT, one.anotherT);
 
+    // Safe because the correct generic type was used when the constructor was bound
+    @SuppressWarnings("unchecked")
     C<Injector> two = (C<Injector>) injector.getInstance(i);
     assertEquals(Stage.DEVELOPMENT, two.stage);
     assertEquals(injector, two.t);
     assertEquals(injector, two.anotherT);
   }
 
+  @Test
   public void testToConstructorBindingsFailsOnRawTypes() throws NoSuchMethodException {
-    final Constructor constructor = C.class.getConstructor(Stage.class, Object.class);
+    @SuppressWarnings("rawtypes") // Unavoidable because class literal uses raw types.
+    final Constructor<C> constructor = C.class.getConstructor(Stage.class, Object.class);
 
     try {
-      Guice.createInjector(new AbstractModule() {
-        protected void configure() {
-          bind(Object.class).toConstructor(constructor);
-        }
-      });
+      Guice.createInjector(
+          new AbstractModule() {
+            @Override
+            protected void configure() {
+              bind(Object.class).toConstructor(constructor);
+            }
+          });
       fail();
     } catch (CreationException expected) {
-      assertContains(expected.getMessage(),
-          "1) T cannot be used as a key; It is not fully specified.",
-          "at " + C.class.getName() + ".<init>(BindingTest.java:",
-          "2) T cannot be used as a key; It is not fully specified.",
-          "at " + C.class.getName() + ".anotherT(BindingTest.java:");
+      assertContains(
+          expected.getMessage(),
+          "T cannot be used as a key; It is not fully specified.",
+          "at BindingTest$C.<init>(BindingTest.java:",
+          "T cannot be used as a key; It is not fully specified.",
+          "at BindingTest$C.anotherT(BindingTest.java:");
     }
   }
 
-/*if[AOP]*/
+  @Test
   public void testToConstructorAndMethodInterceptors() throws NoSuchMethodException {
+    assumeTrue(InternalFlags.isBytecodeGenEnabled());
+
     final Constructor<D> constructor = D.class.getConstructor(Stage.class);
     final AtomicInteger count = new AtomicInteger();
-    final MethodInterceptor countingInterceptor = new MethodInterceptor() {
-      public Object invoke(MethodInvocation methodInvocation) throws Throwable {
-        count.incrementAndGet();
-        return methodInvocation.proceed();
-      }
-    };
+    final MethodInterceptor countingInterceptor =
+        new MethodInterceptor() {
+          @Override
+          public Object invoke(MethodInvocation methodInvocation) throws Throwable {
+            count.incrementAndGet();
+            return methodInvocation.proceed();
+          }
+        };
 
-    Injector injector = Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(Object.class).toConstructor(constructor);
-        bindInterceptor(Matchers.any(), Matchers.any(), countingInterceptor);
-      }
-    });
+    Injector injector =
+        Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                bind(Object.class).toConstructor(constructor);
+                bindInterceptor(Matchers.any(), Matchers.any(), countingInterceptor);
+              }
+            });
 
     D d = (D) injector.getInstance(Object.class);
-    d.hashCode();
-    d.hashCode();
+    int unused = d.hashCode();
+    int unused2 = d.hashCode();
     assertEquals(2, count.get());
   }
-/*end[AOP]*/
 
+  @Test
   public void testInaccessibleConstructor() throws NoSuchMethodException {
     final Constructor<E> constructor = E.class.getDeclaredConstructor(Stage.class);
 
-    Injector injector = Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(E.class).toConstructor(constructor);
-      }
-    });
+    Injector injector =
+        Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                bind(E.class).toConstructor(constructor);
+              }
+            });
 
     E e = injector.getInstance(E.class);
     assertEquals(Stage.DEVELOPMENT, e.stage);
   }
 
+  @Test
   public void testToConstructorAndScopes() throws NoSuchMethodException {
     final Constructor<F> constructor = F.class.getConstructor(Stage.class);
 
@@ -323,14 +388,17 @@ public class BindingTest extends TestCase {
     final Key<Object> n = Key.get(Object.class, named("N")); // "N" instances
     final Key<Object> r = Key.get(Object.class, named("R")); // a regular binding
 
-    Injector injector = Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(d).toConstructor(constructor);
-        bind(s).toConstructor(constructor).in(Singleton.class);
-        bind(n).toConstructor(constructor).in(Scopes.NO_SCOPE);
-        bind(r).to(F.class);
-      }
-    });
+    Injector injector =
+        Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                bind(d).toConstructor(constructor);
+                bind(s).toConstructor(constructor).in(Singleton.class);
+                bind(n).toConstructor(constructor).in(Scopes.NO_SCOPE);
+                bind(r).to(F.class);
+              }
+            });
 
     assertDistinct(injector, 1, d, d, d, d);
     assertDistinct(injector, 1, s, s, s, s);
@@ -347,38 +415,46 @@ public class BindingTest extends TestCase {
     assertEquals(expectedCount, builder.build().size());
   }
 
+  @Test
   public void testToConstructorSpiData() throws NoSuchMethodException {
     final Set<TypeLiteral<?>> heardTypes = Sets.newHashSet();
 
     final Constructor<D> constructor = D.class.getConstructor(Stage.class);
-    final TypeListener listener = new TypeListener() {
-      public <I> void hear(TypeLiteral<I> type, TypeEncounter<I> encounter) {
-        if (!heardTypes.add(type)) {
-          fail("Heard " + type + " multiple times!");
-        }
-      }
-    };
+    final TypeListener listener =
+        new TypeListener() {
+          @Override
+          public <I> void hear(TypeLiteral<I> type, TypeEncounter<I> encounter) {
+            if (!heardTypes.add(type)) {
+              fail("Heard " + type + " multiple times!");
+            }
+          }
+        };
 
-    Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(Object.class).toConstructor(constructor);
-        bind(D.class).toConstructor(constructor);
-        bindListener(Matchers.any(), listener);
-      }
-    });
+    Guice.createInjector(
+        new AbstractModule() {
+          @Override
+          protected void configure() {
+            bind(Object.class).toConstructor(constructor);
+            bind(D.class).toConstructor(constructor);
+            bindListener(Matchers.any(), listener);
+          }
+        });
     
-    assertEquals(ImmutableSet.of(TypeLiteral.get(Stage.class), TypeLiteral.get(D.class)),
-        heardTypes);
+    assertEquals(ImmutableSet.of(TypeLiteral.get(D.class)), heardTypes);
   }
 
+  @Test
   public void testInterfaceToImplementationConstructor() throws NoSuchMethodException {
     final Constructor<CFoo> constructor = CFoo.class.getDeclaredConstructor();
 
-    Injector injector = Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(IFoo.class).toConstructor(constructor);
-      }
-    });
+    Injector injector =
+        Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                bind(IFoo.class).toConstructor(constructor);
+              }
+            });
 
     injector.getInstance(IFoo.class);
   }
@@ -386,14 +462,18 @@ public class BindingTest extends TestCase {
   public static interface IFoo {}
   public static class CFoo implements IFoo {}
 
+  @Test
   public void testGetAllBindings() {
-    Injector injector = Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(D.class).toInstance(new D(Stage.PRODUCTION));
-        bind(Object.class).to(D.class);
-        getProvider(new Key<C<Stage>>() {});
-      }
-    });
+    Injector injector =
+        Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                bind(D.class).toInstance(new D(Stage.PRODUCTION));
+                bind(Object.class).to(D.class);
+                getProvider(new Key<C<Stage>>() {});
+              }
+            });
 
     Map<Key<?>,Binding<?>> bindings = injector.getAllBindings();
     assertEquals(ImmutableSet.of(Key.get(Injector.class), Key.get(Stage.class), Key.get(D.class),
@@ -417,12 +497,16 @@ public class BindingTest extends TestCase {
     assertEquals(injector, bindings.get(Key.get(Injector.class)).getProvider().get());
   }
 
+  @Test
   public void testGetAllServletBindings() throws Exception {
-    Injector injector = Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-        bind(F.class); // an explicit binding that uses a JIT binding for a constructor
-      }
-    });
+    Injector injector =
+        Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                bind(F.class); // an explicit binding that uses a JIT binding for a constructor
+              }
+            });
     injector.getAllBindings();
   }
 
@@ -460,7 +544,8 @@ public class BindingTest extends TestCase {
       this.stage = stage;
     }
   }
-  
+
+  @Test
   public void testTurkeyBaconProblemUsingToConstuctor() {
     Injector injector = Guice.createInjector(new AbstractModule() {
       @SuppressWarnings("unchecked")
@@ -468,6 +553,7 @@ public class BindingTest extends TestCase {
       public void configure() {
         bind(Bacon.class).to(UncookedBacon.class);
         bind(Bacon.class).annotatedWith(named("Turkey")).to(TurkeyBacon.class);
+        bind(Bacon.class).annotatedWith(named("Tofu")).to(TofuBacon.class);
         bind(Bacon.class).annotatedWith(named("Cooked")).toConstructor(
             (Constructor)InjectionPoint.forConstructorOf(Bacon.class).getMember());
       }
@@ -482,21 +568,117 @@ public class BindingTest extends TestCase {
     
     Bacon cookedBacon = injector.getInstance(Key.get(Bacon.class, named("Cooked")));
     assertEquals(Food.PORK, cookedBacon.getMaterial());
-    assertTrue(cookedBacon.isCooked());    
+    assertTrue(cookedBacon.isCooked());
+
+    try {
+      // Turkey typo, missing a letter...
+      injector.getInstance(Key.get(Bacon.class, named("Turky")));
+      fail();
+    } catch (ConfigurationException e) {
+      String msg = e.getMessage();
+      assertContains(
+          msg,
+          "Guice configuration errors:",
+          "No implementation for BindingTest$Bacon annotated with @Named("
+              + Annotations.memberValueString("value", "Turky")
+              + ") was bound.",
+          "Did you mean?",
+          "* BindingTest$Bacon annotated with @Named("
+              + Annotations.memberValueString("value", "Turkey")
+              + ")",
+          "* BindingTest$Bacon annotated with @Named("
+              + Annotations.memberValueString("value", "Tofu")
+              + ")",
+          "1 more binding with other annotations.");
+    }
   }
-  
-  enum Food { TURKEY, PORK }
-  
+
+  @Test
+  public void testMissingAnnotationOneChoice() {
+    Injector injector = Guice.createInjector(new AbstractModule() {
+      @SuppressWarnings("unchecked")
+      @Override
+      public void configure() {
+        bind(Bacon.class).annotatedWith(named("Turkey")).to(TurkeyBacon.class);
+      }
+    });
+
+    try {
+      // turkey typo (should be Upper case)...
+      injector.getInstance(Key.get(Bacon.class, named("turkey")));
+      fail();
+    } catch (ConfigurationException e) {
+      String msg = e.getMessage();
+      assertContains(msg, "Guice configuration errors:");
+      assertContains(
+          msg,
+          "No implementation for BindingTest$Bacon annotated with @Named("
+              + Annotations.memberValueString("value", "turkey")
+              + ") was bound.",
+          "Did you mean?",
+          "* BindingTest$Bacon annotated with @Named("
+              + Annotations.memberValueString("value", "Turkey")
+              + ")");
+    }
+  }
+
+  enum Food { TURKEY, PORK, TOFU }
+
   private static class Bacon {
     public Food getMaterial() { return Food.PORK; }
     public boolean isCooked() { return true; }
   }
 
   private static class TurkeyBacon extends Bacon {
+    @Override
     public Food getMaterial() { return Food.TURKEY; }
   }
 
+  private static class TofuBacon extends Bacon {
+    @Override
+    public Food getMaterial() { return Food.TOFU; }
+  }
+
   private static class UncookedBacon extends Bacon {
+    @Override
     public boolean isCooked() { return false; }
   }
+
+  @Test
+  public void testMissingAnnotationRelated() {
+    try {
+      final TypeLiteral<List<Butter>> list = new TypeLiteral<List<Butter>>() {};
+
+      Guice.createInjector(new AbstractModule() {
+        @SuppressWarnings("unchecked")
+        @Override
+        public void configure() {
+          bind(list).toInstance(butters);
+          bind(Sandwitch.class).to(ButterSandwitch.class);
+        }
+      });
+
+      fail();
+    } catch (CreationException e) {
+      final String msg = e.getMessage();
+      assertContains(
+          msg,
+          "Unable to create injector, see the following errors:",
+          "Did you mean?",
+          "List<BindingTest$Butter> bound at BindingTest$24.configure");
+    }
+  }
+
+  private static List<Butter> butters = new ArrayList<>();
+
+  private static interface Sandwitch {};
+
+  private static interface Butter {};
+
+  private static class ButterSandwitch implements Sandwitch {
+    private ButterSandwitch() {};
+
+    @Inject
+    ButterSandwitch(@Named("unsalted") Butter butter) {};
+  }
 }
