@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2006 Google Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,11 +16,12 @@
 
 package com.google.inject.example;
 
+import static com.google.inject.example.JndiProvider.fromJndi;
+
 import com.google.inject.AbstractModule;
 import com.google.inject.CreationException;
 import com.google.inject.Guice;
 import com.google.inject.Injector;
-import static com.google.inject.example.JndiProvider.fromJndi;
 import javax.naming.Context;
 import javax.naming.InitialContext;
 import javax.sql.DataSource;
@@ -28,15 +29,17 @@ import javax.sql.DataSource;
 class JndiProviderClient {
 
   public static void main(String[] args) throws CreationException {
-    Injector injector = Guice.createInjector(new AbstractModule() {
-      protected void configure() {
-// Bind Context to the default InitialContext.
-bind(Context.class).to(InitialContext.class);
+    Injector injector =
+        Guice.createInjector(
+            new AbstractModule() {
+              @Override
+              protected void configure() {
+                // Bind Context to the default InitialContext.
+                bind(Context.class).to(InitialContext.class);
 
-// Bind to DataSource from JNDI.
-bind(DataSource.class)
-    .toProvider(fromJndi(DataSource.class, "..."));
-      }
-    });
+                // Bind to DataSource from JNDI.
+                bind(DataSource.class).toProvider(fromJndi(DataSource.class, "..."));
+              }
+            });
   }
 }
