@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2008 Google Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,12 +17,12 @@
 package com.google.inject.servlet;
 
 import java.io.IOException;
-import javax.servlet.Filter;
-import javax.servlet.FilterChain;
-import javax.servlet.FilterConfig;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
+import jakarta.servlet.Filter;
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.FilterConfig;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
 
 /**
  * Used in unit tests to verify the EDSL.
@@ -32,20 +32,20 @@ import javax.servlet.ServletResponse;
 public class DummyFilterImpl implements Filter {
   int num;
 
-  public DummyFilterImpl() {
-  }
+  public DummyFilterImpl() {}
 
   public DummyFilterImpl(int num) {
     this.num = num;
   }
 
-  public void init(FilterConfig filterConfig) throws ServletException {
-  }
+  @Override
+  public void init(FilterConfig filterConfig) throws ServletException {}
 
-  public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse,
-      FilterChain filterChain) throws IOException, ServletException {
-  }
+  @Override
+  public void doFilter(
+      ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain)
+      throws IOException, ServletException {}
 
-  public void destroy() {
-  }
+  @Override
+  public void destroy() {}
 }
