@@ -24,6 +24,7 @@ import static java.lang.annotation.ElementType.FIELD;
 import static java.lang.annotation.ElementType.METHOD;
 import static java.lang.annotation.ElementType.PARAMETER;
 import static java.lang.annotation.RetentionPolicy.RUNTIME;
+import static org.mockito.Mockito.mock;
 
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.Lists;
@@ -48,18 +49,18 @@ import java.io.Serializable;
 import java.lang.annotation.Retention;
 import java.lang.annotation.Target;
 import java.util.Map;
-import javax.servlet.Filter;
-import javax.servlet.FilterChain;
-import javax.servlet.FilterConfig;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletRequestWrapper;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpServletResponseWrapper;
-import javax.servlet.http.HttpSession;
+import jakarta.servlet.Filter;
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.FilterConfig;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletRequestWrapper;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpServletResponseWrapper;
+import jakarta.servlet.http.HttpSession;
 import junit.framework.TestCase;
 
 /** @author crazybob@google.com (Bob Lee) */
@@ -474,6 +475,7 @@ public class ServletTest extends TestCase {
               }
             });
     final HttpServletRequest request = newFakeHttpServletRequest();
+    final HttpServletResponse response = mock(HttpServletResponse.class); // spec requires non-null
     FilterChain filterChain =
         new FilterChain() {
           @Override
@@ -483,13 +485,13 @@ public class ServletTest extends TestCase {
         };
 
     try {
-      new GuiceFilter().doFilter(request, null, filterChain);
+      new GuiceFilter().doFilter(request, response, filterChain);
       fail();
     } catch (RuntimeException e) {
       assertSame(servletException, e);
     }
     try {
-      injector.getInstance(GuiceFilter.class).doFilter(request, null, filterChain);
+      injector.getInstance(GuiceFilter.class).doFilter(request, response, filterChain);
       fail();
     } catch (RuntimeException e) {
       assertSame(servletException, e);
@@ -497,7 +499,7 @@ public class ServletTest extends TestCase {
     try {
       injector
           .getInstance(Key.get(GuiceFilter.class, ScopingOnly.class))
-          .doFilter(request, null, filterChain);
+          .doFilter(request, response, filterChain);
       fail();
     } catch (RuntimeException e) {
       assertSame(chainException, e);
